@@ -4,10 +4,15 @@ Make gio's logo.
 Author: Matt Hall
 License: Apache 2.0
 """
-import numpy as np
-import matplotlib.pyplot as plt
-from matplotlib.cm import get_cmap
 import hashlib
+import numpy as np
+
+try:
+    import matplotlib.pyplot as plt
+    from matplotlib.cm import get_cmap
+    mpl_installed = True
+except ImportError:
+    mpl_installed = False
 
 from .random import generate_random_surface
 
@@ -16,7 +21,11 @@ def plot(ax=None, fname=None):
     Plots as a side effect. Pass in a 3d Axes if you want. Pass a filename
     to save the plot.
     """
-    seed = int(hashlib.sha1("gi/o".encode()).hexdigest(), 16)
+    if not mpl_installed:
+        m = 'matplotlib is not installed; install it to use this function.'
+        raise ImportError(m)
+
+    seed = int(hashlib.sha1("gio".encode()).hexdigest(), 16)
 
     if ax is None:
         fig = plt.figure(figsize=(12, 12))
@@ -31,11 +40,10 @@ def plot(ax=None, fname=None):
     Z = 240 * Z + 240
     ax.axis('off')
 
+    ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap='RdBu')
+    ax.plot_wireframe(X, Y, Z, color='k', lw=0.5, alpha=0.75)
     c = get_cmap('gray')
-    ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap='viridis')
-    ax.plot_wireframe(X, Y, Z, color='white', lw=0.5)
-    ax.text(-14, 20, 220, r"$\mathbf{gi\ o}$", size=240, zorder=10, color=c(0.4))
-    ax.text(6, 32, 220, r"$\mathbf{/}$", size=240, zorder=10, color=c(0.7))
+    ax.text(-10, 20, 220, r"$\mathbf{gio}$", size=240, zorder=10, color=c(0.15))
     ax.set_zlim(0, 1200)
 
     if fname is not None:
@@ -43,4 +51,4 @@ def plot(ax=None, fname=None):
 
     plt.show()
 
-    return ax
\ No newline at end of file
+    return ax
